@@ -7,9 +7,10 @@ use warnings;
 use Sub::Exporter;
 use Test::Builder;
 
+use List::MoreUtils 'all';
 use Moose::Util 'does_role', 'find_meta';
 
-our $VERSION   = '0.92';
+our $VERSION   = '1.08';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -17,6 +18,7 @@ my @exports = qw[
     meta_ok
     does_ok
     has_attribute_ok
+    with_immutable
 ];
 
 Sub::Exporter::setup_exporter({
@@ -71,9 +73,19 @@ sub has_attribute_ok ($$;$) {
     }
 }
 
+sub with_immutable (&@) {
+    my $block = shift;
+    my $before = $Test->current_test;
+    $block->();
+    $_->meta->make_immutable for @_;
+    $block->();
+    my $num_tests = $Test->current_test - $before;
+    return all { $_ } ($Test->summary)[-$num_tests..-1];
+}
+
 1;
 
 __END__
 
-#line 168
+#line 183
 
